@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(perl2xml xmlformat xml2perlbase perlbase2xml xpath);
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 use HTML::Parser;
 
@@ -136,6 +136,7 @@ sub xml2perlbase {
 	my $prs = HTML::Parser->new(api_version => 3);
 	$prs->xml_mode(1);
 	$prs->utf8_mode(1);
+	$prs->marked_sections(1);
 
 	my $t = {};
 	# {
@@ -167,6 +168,7 @@ sub xml2perlbase {
 
 	$prs->handler(end => sub {
 		my ($prs, $tagname) = @_;
+		@p > 1 or return;
 		my $v = $p[-2]{$n[-1]}[-1]{''};
 		if (ref $v eq "HASH" and keys %$v == 0 or $v eq "") {
 			delete $p[-2]{$n[-1]}[-1]{''};
@@ -234,7 +236,7 @@ sub xpath {
 sub _xpath {
 	my ($tree, $path, @path) = @_;
 	my ($k, $i) = $path =~ m/^(.+?)(?:\[(\d+)\])?$/;
-	if ($$tree{$k}) {
+	if (ref $tree eq "HASH" and $$tree{$k}) {
 		my @sub_tree = ();
 		if ($i) {
 			push @sub_tree, $$tree{$k}[$i - 1];
